@@ -124,3 +124,65 @@ def savedialog(filter="All (*.*)", title="Save file", directory:str=None) -> str
     """
     return _savedialog_qt(filename=filename, filter=filter, title=title, 
                           directory=directory)
+
+def combowin(options: List[str]) -> Opt[str]:
+    from PyQt5 import QtCore, QtGui, QtWidgets
+    from PyQt5.QtCore import Qt, QSortFilterProxyModel
+    from PyQt5.QtWidgets import QCompleter, QComboBox
+
+    class ExtendedComboBox(QComboBox):
+        def __init__(self, parent=None):
+            super(ExtendedComboBox, self).__init__(parent)
+
+            self.setFocusPolicy(Qt.StrongFocus)
+            self.setEditable(True)
+
+            # add a filter model to filter matching items
+            self.pFilterModel = QSortFilterProxyModel(self)
+            self.pFilterModel.setFilterCaseSensitivity(Qt.CaseInsensitive)
+            self.pFilterModel.setSourceModel(self.model())
+
+            # add a completer, which uses the filter model
+            self.completer = QCompleter(self.pFilterModel, self)
+            # always show all (filtered) completions
+            self.completer.setCompletionMode(QCompleter.UnfilteredPopupCompletion)
+            self.setCompleter(self.completer)
+
+            # connect signals
+            self.lineEdit().textEdited.connect(self.pFilterModel.setFilterFixedString)
+            self.completer.activated.connect(self.on_completer_activated)
+
+        # on selection of an item from the completer, select the corresponding item from combobox
+        def on_completer_activated(self, text):
+            if text:
+                index = self.findText(text)
+                self.setCurrentIndex(index)
+                self.activated[str].emit(self.itemText(index))
+
+        # on model change, update the models of the filter and completer as well
+        def setModel(self, model):
+            super(ExtendedComboBox, self).setModel(model)
+            self.pFilterModel.setSourceModel(model)
+            self.completer.setModel(self.pFilterModel)
+
+        # on model column change, update the model column of the filter and completer as well
+        def setModelColumn(self, column):
+            self.completer.setCompletionColumn(column)
+            self.pFilterModel.setFilterKeyColumn(column)
+            super(ExtendedComboBox, self).setModelColumn(column)
+
+    from PyQt5.QtWidgets import QApplication
+    from PyQt5.QtCore import QStringListModel
+    app = QApplication([])
+
+    combo = ExtendedComboBox()
+
+    # either fill the standard model of the combobox
+    combo.addItems(options)
+
+    # or use another model
+    # combo.setModel(QStringListModel(string_list))
+
+    combo.resize(300, 40)
+    combo.show()
+    app.exec_()
